<p align="center">
    <picture>
        <source media="(prefers-color-scheme: dark)" srcset=".github/assets/logo/dark.svg"/>
        <img alt="ZenRows Logo" src=".github/assets/logo/light.svg" width="300" />
    </picture>
</p>

<p align="center">
    <a href="https://docs.zenrows.com?utm_source=github.com&utm_medium=social&utm_campaign=zenrows-go-sdk">Documentation</a>
    <span>&nbsp;·&nbsp;</span>
    <a href="https://www.zenrows.com/pricing?utm_source=github.com&utm_medium=social&utm_campaign=zenrows-go-sdk">Pricing</a>
</p>
<br/>

# ZenRows Middleware for Scrapy

ZenRows® offers an advanced web scraping suite designed to simplify data collection, processing, and management. Whether you're looking for scalable data extraction, a reliable browser solution for handling dynamic websites, or residential proxies to access location-specific content, we provide the ideal tools for your unique needs.

This repository hosts `scrapy-zenrows`, the Scrapy middleware that allows you to easily integrate Scrapy with the ZenRows Scraper API for web scraping. Each folder includes installation instructions and detailed documentation.

## Table of Contents

- [Scrapy-ZenRows Middleware](#scrapy-zenrows-middleware)
  - [The ZenRows Scraper API](#the-zenrows-scraper-api)
- [Contributing](#contributing)
- [License](#license)

## Scrapy-ZenRows Middleware

### The ZenRows Scraper API

> The ZenRows® Scraper API is an efficient, and hassle-free solution that lets you extract data from web pages at scale while overcoming the common challenges posed by modern websites, including CAPTCHAs, WAFs, and other anti-bot mechanisms.

**Directory**: [scrapy_zenrows](scrapy_zenrows)
The scrapy-zenrows middlware brings all the functionalities of the ZenRows® Scraper API to Scrapy with straightforward implementation.

👉🏼 [Installation and Usage](scrapy_zenrows/README.md)

👉🏼 [API Reference](https://docs.zenrows.com/scraper-api/api-reference)

## Contributing

Contributions to the SDKs are welcome! See [CONTRIBUTING.md](./CONTRIBUTING.md) for more information on how to contribute to the repository.

## License

This project is licensed under the MIT License - see the [LICENSE](./LICENSE) file for details.
